<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="2.0"
				xmlns="http://www.w3.org/1999/xhtml">

<!-- ======================================================== -->
<!-- Pievienojam kopējās transformācijas -->
<xsl:import href="lu_html.xsl"/>

<!-- ======================================================== -->
<xsl:output encoding="utf-8" method="html" doctype-public="//W3C//DTD HTML 4.01 Transitional//EN" doctype-system="http://www.w3.org/TR/html4/loose.dtd"/>

<xsl:output name="section-format" encoding="utf-8" indent="yes" method="html" doctype-public="//W3C//DTD HTML 4.01 Transitional//EN" doctype-system="http://www.w3.org/TR/html4/loose.dtd"/>

<!-- ======================================================================= -->
<!-- Galvenās struktūras procesēšana -->
<xsl:template match="preface | chapter">
	<xsl:variable name="filename">
		<xsl:call-template name="generate_filename"/>
	</xsl:variable>
	<xsl:result-document href="{$filename}" format="section-format" validation="strip">
		<html>
		<xsl:call-template name="head">
			<xsl:with-param name="title">
				<xsl:apply-templates select="title" mode="book_toc"/>
			</xsl:with-param>
		</xsl:call-template>
		<body>
		<xsl:apply-templates select="*[not(self::sect1 or self::section)]"/>
		<xsl:if test="*[not(self::sect1 or self::section)]//footnote">
			<xsl:call-template name="generate_footnotes">
				<xsl:with-param name="footnotes" select="*[not(self::sect1 or self::section)]//footnote"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates select="sect1 | section"/>
		</body>
		</html>
	</xsl:result-document>
</xsl:template>

<xsl:template match="preface/title | chapter/title" mode="book_toc">
	<xsl:if test="not(../@label='none')">
		<xsl:call-template name="get_chapter_number"/>
		<xsl:text>&#160;</xsl:text>
	</xsl:if>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="sect1">
	<xsl:variable name="filename">
		<xsl:call-template name="generate_filename"/>
	</xsl:variable>
	<xsl:result-document href="{$filename}" format="section-format" validation="strip">
		<html>
		<xsl:call-template name="head">
			<xsl:with-param name="title">
				<xsl:apply-templates select="title" mode="book_toc"/>
			</xsl:with-param>
		</xsl:call-template>
		<body>
		<xsl:apply-templates select="*[not(self::sect2)]"/>
		<xsl:if test="*[not(self::sect2)]//footnote">
				<xsl:call-template name="generate_footnotes">
					<xsl:with-param name="footnotes" select="*[not(self::sect2)]//footnote"/>
				</xsl:call-template>
		</xsl:if>
		<xsl:apply-templates select="sect2"/>
		</body>
		</html>
	</xsl:result-document>
</xsl:template>

<xsl:template match="sect2">
	<xsl:variable name="filename">
		<xsl:call-template name="generate_filename"/>
	</xsl:variable>
	<xsl:choose>
		<xsl:when test="not(ancestor::chapter or ancestor::preface or ancestor::appendix)">
			<xsl:result-document href="{$filename}" format="section-format" validation="strip">
				<html>
				<xsl:call-template name="head">
					<xsl:with-param name="title">
						<xsl:apply-templates select="title" mode="book_toc"/>
					</xsl:with-param>
				</xsl:call-template>
				<body>
				<xsl:apply-templates select="*[not(self::sect3)]"/>
				<xsl:if test="*[not(self::sect3)]//footnote">
						<xsl:call-template name="generate_footnotes">
							<xsl:with-param name="footnotes" select="*[not(self::sect3)]//footnote"/>
						</xsl:call-template>
				</xsl:if>
				<xsl:apply-templates select="sect3"/>
				</body>
				</html>
			</xsl:result-document>
		</xsl:when>
		<xsl:otherwise>
			<xsl:apply-templates select="*[not(self::sect3)]"/>
			<xsl:if test="*[not(self::sect3)]//footnote">
					<xsl:call-template name="generate_footnotes">
						<xsl:with-param name="footnotes" select="*[not(self::sect3)]//footnote"/>
					</xsl:call-template>
			</xsl:if>
			<xsl:apply-templates select="sect3"/>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="sect1/title | sect2/title" mode="book_toc">
	<xsl:call-template name="get_sect_number"/>
	<xsl:text>&#160;</xsl:text>
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="bibliography">
	<xsl:variable name="filename">
		<xsl:call-template name="generate_filename"/>
	</xsl:variable>
	<xsl:variable name="title">
		<xsl:choose>
			<xsl:when test="title">
				<xsl:apply-templates select="title"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="get_lang_string">
					<xsl:with-param name="lang" select="@lang"/>
					<xsl:with-param name="code" select="'bibliography'"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:variable>
	<xsl:result-document href="{$filename}" format="section-format" validation="strip">
		<html>
		<xsl:call-template name="head">
			<xsl:with-param name="title" select="$title"/>
		</xsl:call-template>
		<body>
		<a>
			<xsl:attribute name="name">
				<xsl:call-template name="node-id"/>
			</xsl:attribute>
		</a>
		<h2>
		<xsl:value-of select="$title"/>
		</h2>
		<div class="bibliography">
			<xsl:apply-templates select="bibliodiv"/>
			<xsl:variable name="biblioutput">
				<xsl:apply-templates select="biblioentry | bibliomixed"/>
			</xsl:variable>
			<xsl:choose>
				<xsl:when test="$bibstyle='date'">
					<xsl:apply-templates select="$biblioutput/*">
							<xsl:sort/>
					</xsl:apply-templates>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates select="$biblioutput"/>
				</xsl:otherwise>
			</xsl:choose>
		</div>
		</body>
		</html>
	</xsl:result-document>
</xsl:template>

<xsl:template match="appendix">
	<xsl:variable name="filename">
		<xsl:call-template name="generate_filename"/>
	</xsl:variable>
	<xsl:result-document href="{$filename}" format="section-format" validation="strip">
		<html>
		<xsl:call-template name="head">
			<xsl:with-param name="title">
				<xsl:call-template name="get_lang_string">
					<xsl:with-param name="lang" select="@lang"/>
					<xsl:with-param name="code" select="'appendix'"/>
					<xsl:with-param name="number">
						<xsl:call-template name="get_appendix_number"/>
					</xsl:with-param>
				</xsl:call-template>
			</xsl:with-param>
		</xsl:call-template>
		<body>
		<xsl:if test="not(preceding-sibling::appendix)">
			<xsl:call-template name="get_lang_string">
				<xsl:with-param name="lang" select="@lang"/>
				<xsl:with-param name="code" select="'appendixes'"/>
			</xsl:call-template>
		</xsl:if>
		<xsl:element name="a">
			<xsl:attribute name="name">
				<xsl:call-template name="node-id"/>
			</xsl:attribute>
		</xsl:element>
		<h3>
			<xsl:call-template name="get_lang_string">
				<xsl:with-param name="lang" select="@lang"/>
				<xsl:with-param name="code" select="'appendix'"/>
				<xsl:with-param name="number">
					<xsl:call-template name="get_appendix_number"/>
				</xsl:with-param>
			</xsl:call-template>
		</h3>
		<xsl:apply-templates/>
		<xsl:if test="descendant::footnote[not(ancestor::sect1)]">
			<xsl:call-template name="generate_footnotes">
				<xsl:with-param name="footnotes" select="descendant::footnote[not(ancestor::sect1)]"/>
			</xsl:call-template>
		</xsl:if>
		</body>
		</html>
	</xsl:result-document>
</xsl:template>
<!-- ======================================================================= -->

<xsl:template name="generate_toc_filename">
	<xsl:choose>
		<xsl:when test="ancestor-or-self::bibliography">
			<xsl:for-each select="ancestor-or-self::bibliography">
				<xsl:call-template name="generate_filename"/>
			</xsl:for-each>
		</xsl:when>
		<xsl:when test="ancestor-or-self::sect2 and not(ancestor::chapter or ancestor::appendix)">
			<xsl:for-each select="ancestor-or-self::sect2">
				<xsl:call-template name="generate_filename"/>
			</xsl:for-each>
		</xsl:when>
		<xsl:when test="ancestor-or-self::sect1">
			<xsl:for-each select="ancestor-or-self::sect1">
				<xsl:call-template name="generate_filename"/>
			</xsl:for-each>
		</xsl:when>
		<xsl:when test="ancestor-or-self::preface">
			<xsl:for-each select="ancestor-or-self::preface">
				<xsl:call-template name="generate_filename"/>
			</xsl:for-each>
		</xsl:when>
		<xsl:when test="ancestor-or-self::chapter">
			<xsl:for-each select="ancestor-or-self::chapter">
				<xsl:call-template name="generate_filename"/>
			</xsl:for-each>
		</xsl:when>
		<xsl:when test="ancestor-or-self::appendix">
			<xsl:for-each select="ancestor-or-self::appendix">
				<xsl:call-template name="generate_filename"/>
			</xsl:for-each>
		</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template name="generate_filename">
	<xsl:variable name="number">
		<xsl:call-template name="get_all_sect_number"/>
	</xsl:variable>
	<xsl:value-of select="format-number($number,'00000')"/>
	<xsl:text>_</xsl:text>
	<xsl:choose>
		<xsl:when test="(ancestor::article|ancestor::book)/@id">
			<xsl:value-of select="(ancestor::article|ancestor::book)/@id"/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:text>tema</xsl:text>
		</xsl:otherwise>
	</xsl:choose>
	<xsl:if test="(self::sect1 and (parent::chapter or parent::preface or parent::appendix)) or (self::sect2 and not(ancestor::chapter or ancestor::preface or ancestor::appendix))">
		<xsl:text>_sub</xsl:text>
	</xsl:if>
	<xsl:text>.html</xsl:text>
</xsl:template>

<!-- Atsauču href atribūtu ģenerēšana, lai parādītos arī faila nosaukums -->
<xsl:template name="generate_href_attribute">
	<xsl:param name="ref"/>
	<xsl:attribute name="href">
		<xsl:for-each select="//*[@id=$ref]">
			<xsl:call-template name="generate_toc_filename"/>
			<xsl:text>#</xsl:text>
			<xsl:call-template name="node-id"/>
		</xsl:for-each>
	</xsl:attribute>
</xsl:template>

<xsl:template name="get_all_sect_number">
	<xsl:number count="preface | chapter | section | sect1 | sect2 | sect3 | sect4 | sect5 | bibliography | appendix" level="any"/>
</xsl:template>

</xsl:stylesheet>
